@@ -100,11 +100,11 @@
 #' @param ... further arguments passed to or from other methods and to control
 #' the document's structure (see details).
 #'
-#' @section Function version: 0.1.3
+#' @section Function version: 0.1.5
 #'
 #' @author
 #' Christoph Burow, University of Cologne (Germany),
-#' Sebastian Kreutzer, Geography & Earth Sciences, Aberystwyth University (United Kingdom) \cr
+#' Sebastian Kreutzer, Institute of Geography, Heidelberg University (Germany) \cr
 #'
 #' @note
 #' This function requires the R packages 'rmarkdown', 'pander' and 'rstudioapi'.
@@ -270,7 +270,7 @@ report_RLum <- function(
 
   # Create and open the file
   file.create(file)
-  tmp <- file(file, open = "w")
+  tmp <- file(file, open = "wt", blocking = TRUE)
 
   # save RDS file
   saveRDS(object, file.rds)
@@ -355,14 +355,14 @@ report_RLum <- function(
 
   }#EndOf::Header
 
+
   # OBJECT ----
   if (structure$main) {
     for (i in 1:nrow(elements)) {
-
       # SKIP ELEMENT?
       # hide @.pid and @.uid if this is a shortened report (default)
       if (elements$bud[i] %in% c(".uid", ".pid") && compact == TRUE)
-        next
+        next();
 
 
       # HEADER
@@ -426,7 +426,7 @@ report_RLum <- function(
           table <- as.character(table)
 
         # exception: surround objects of class "call" with <pre> tags to prevent
-        # HTML autoformatting
+        # HTML auto formatting
         if (elements$class[i] == "call") {
           table <- capture.output(table)
           writeLines("<pre>", tmp)
@@ -440,19 +440,18 @@ report_RLum <- function(
         if (options$short_table) {
           if (is.matrix(table) || is.data.frame(table)) {
             if (nrow(table) > 15) {
+              text <- pander::pander_return(
+                rbind(head(table, 5), tail(table, 5)),
+                caption = "shortened (only first and last five rows shown)")
 
-              writeLines(pander::pander_return(rbind(head(table, 5),
-                                                     tail(table, 5)),
-                                               caption = "shortened (only first and last five rows shown)"), tmp)
+              writeLines(text, tmp)
               next
-
             }
           }
         }
 
         # write table using pander and end each table with a horizontal line
-        writeLines(pander::pander_return(table),
-                   tmp)
+        writeLines(suppressWarnings(pander::pander_return(table)), tmp)
         writeLines("\n\n<hr>", tmp)
 
       }
@@ -476,14 +475,15 @@ report_RLum <- function(
     writeLines(paste("<hr># File \n\n"), tmp)
 
     writeLines(paste0("<code>",
-                      "<a href='", paste0("file:///", gsub("\\~\\/", "", file.rds)),"' download>",
+                      "<a href='", normalizePath(file.rds),"' download>",
                       "Click here to access the data file", "</a>",
                       "</code>"), tmp)
 
-    writeLines(paste("\nThe R object was saved to <span style='color:#428bca'>", file.rds, "</span>.",
+    writeLines(paste("\nThe R object was saved to <span style='color:#428bca'>", normalizePath(file.rds),
+                     "</span>.",
                      "To import the object into your R session with the following command:",
                      paste0("<pre>",
-                            "x <- readRDS('", file.rds, "')",
+                            "x <- readRDS('", normalizePath(file.rds), "')",
                             "</pre>"),
                      "**NOTE:** If you moved the file to another directory or",
                      "renamed the file you need to change the path/filename in the",
@@ -520,15 +520,15 @@ report_RLum <- function(
       writeLines(paste0(
         "```{r}\n",
         "library(Luminescence) \n",
-        "x <- readRDS('", file.rds,"') \n",
+        "x <- readRDS('", normalizePath(file.rds),"') \n",
         plotCommand,
         "```"),
         tmp)
 
       if (inherits(object, "RLum.Results")) {
-
         # AGE MODELS ----
-        models <- c("calc_CommonDose",
+        models <- c("calc_AverageDose",
+                    "calc_CommonDose",
                     "calc_CentralDose",
                     "calc_FiniteMixture",
                     "calc_MinDose",
@@ -551,10 +551,9 @@ report_RLum <- function(
     }
   }#EndOf::Plot
 
+  close(tmp)
   ## ------------------------------------------------------------------------ ##
   ## CLOSE & RENDER ----
-  close(tmp)
-  on.exit(closeAllConnections())
   rmarkdown::render(file, clean = clean, quiet = quiet)
 
   ## ------------------------------------------------------------------------ ##
