@@ -37,7 +37,7 @@
 #' either [Risoe.BINfileData-class] or [RLum.Analysis-class]
 #'
 #' @param cleanup_level [character] (*with default*):
-#' selects the level for the cleanup of the input data sets.
+#' selects the level for the clean-up of the input data sets.
 #' Two options are allowed: `"curve"` or `"aliquot"`:
 #'
 #' - If  `"curve"` is selected every single curve marked as `invalid` is removed.
@@ -51,6 +51,9 @@
 #' @param plot [logical] (*with default*):
 #' enables or disables the graphical feedback
 #'
+#' @param ... further parameters to control the plot output; if selected.
+#' Supported arguments `main`, `ylim`
+#'
 #' @return
 #' The function returns
 #'
@@ -92,11 +95,11 @@
 #' that Reg0 curves within a SAR cycle are removed as well. Therefore it is
 #' strongly recommended to use the argument `cleanup = TRUE` carefully.
 #'
-#' @section Function version: 0.2.1
+#' @section Function version: 0.2.3
 #'
 #'
 #' @author
-#' Sebastian Kreutzer, Geography & Earth Sciences, Aberystwyh University (United Kingdom)
+#' Sebastian Kreutzer, Institute of Geography, Heidelberg University (Germany)
 #'
 #'
 #' @seealso [Risoe.BINfileData-class], [RLum.Analysis-class], [write_R2BIN],
@@ -136,12 +139,13 @@
 #' @md
 #' @export
 verify_SingleGrainData <- function(
-  object,
-  threshold = 10,
-  cleanup = FALSE,
-  cleanup_level = 'aliquot',
-  verbose = TRUE,
-  plot = FALSE
+    object,
+    threshold = 10,
+    cleanup = FALSE,
+    cleanup_level = 'aliquot',
+    verbose = TRUE,
+    plot = FALSE,
+    ...
 ){
 
 
@@ -152,26 +156,26 @@ verify_SingleGrainData <- function(
 
   # Self Call -----------------------------------------------------------------------------------
   if(is(object, "list")){
-
-    results <- lapply(1:length(object), function(x) {
+    results <- .warningCatcher(lapply(1:length(object), function(x) {
       verify_SingleGrainData(
         object = object[[x]],
         threshold = threshold,
         cleanup = cleanup,
         cleanup_level = cleanup_level,
         verbose = verbose,
-        plot = plot
+        plot = plot,
+        main = paste0("Record #",x)
       )
-    })
+    }))
 
-      ##account for cleanup
-      if(cleanup){
-        return(results)
+    ##account for cleanup
+    if(cleanup){
+      return(results)
 
-      }else{
-        return(merge_RLum(results))
+    }else{
+      return(merge_RLum(results))
 
-      }
+    }
 
   }
 
@@ -179,106 +183,12 @@ verify_SingleGrainData <- function(
   ##RisoeBINfileData
   if(is(object, "Risoe.BINfileData")){
 
-      ##run test on DATA slot
-        ##MEAN + SD
-        temp.results_matrix <- lapply(X = object@DATA, FUN = function(x){
-            c(mean(x), var(x))
-
-        })
-
-        temp.results_matrix <- do.call(rbind,  temp.results_matrix)
-
-        ##DIFF
-        temp.results_matrix_RATIO <- temp.results_matrix[,2]/temp.results_matrix[,1]
-
-        ##SEL
-        temp.results_matrix_VALID <- temp.results_matrix_RATIO > threshold
-
-      ##combine everything to in a data.frame
-        selection <- data.frame(
-          POSITION = object@METADATA$POSITION,
-          GRAIN = object@METADATA$GRAIN,
-          MEAN = temp.results_matrix[, 1],
-          VAR = temp.results_matrix[, 2],
-          RATIO = temp.results_matrix_RATIO,
-          THRESHOLD = rep_len(threshold, length(object@DATA)),
-          VALID = temp.results_matrix_VALID
-        )
-
-        ##get unique pairs for POSITION and GRAIN for VALID == TRUE
-        unique_pairs <- unique(
-          selection[selection[["VALID"]], c("POSITION", "GRAIN")])
-
-
-        if(cleanup_level == "aliquot"){
-          selection_id <- sort(unlist(lapply(1:nrow(unique_pairs), function(x) {
-            which(
-              .subset2(selection, 1) == .subset2(unique_pairs, 1)[x] &
-                .subset2(selection, 2) == .subset2(unique_pairs, 2)[x]
-            )
-
-
-          })))
-
-
-        }else{
-
-         ##reduce data to TRUE selection
-         selection_id <- which(selection[["VALID"]])
-
-        }
-
-
-      ##select output on the chosen input
-      if(cleanup){
-
-        ##selected wanted elements
-        object@DATA <- object@DATA[selection_id]
-        object@METADATA <- object@METADATA[selection_id,]
-        object@METADATA$ID <- 1:length(object@DATA)
-
-
-        ##print message
-        selection_id <- paste(selection_id, collapse = ", ")
-        if(verbose){
-          cat(paste0("\n[verify_SingleGrainData()] Risoe.BINfileData object reduced to records: \n", selection_id))
-          cat("\n\n[verify_SingleGrainData()] Risoe.BINfileData object record index reset.")
-
-        }
-
-         ##return
-        return_object <- object
-
-      }else{
-        return_object <- set_RLum(
-          class = "RLum.Results",
-          data = list(
-            unique_pairs =  unique_pairs,
-            selection_id = selection_id,
-            selection_full = selection),
-          info = list(call = sys.call())
-        )
-
-      }
-
-
-  ##++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-  ##RLum.Analysis and list with RLum.Analysis objects
-  ## ... and yes it make sense not to mix that up with the code above
-  }else if(is(object,"RLum.Analysis")){
-
-    ##first extract all count values from all curves
-    object_list <- lapply(get_RLum(object), function(x){
-        ##yes, would work differently, but it is faster
-        x@data[,2]
-
-    })
-
+    ##run test on DATA slot
     ##MEAN + SD
-    temp.results_matrix <- lapply(X = object_list, FUN = function(x){
+    temp.results_matrix <- lapply(X = object@DATA, FUN = function(x){
       c(mean(x), var(x))
 
-     })
+    })
 
     temp.results_matrix <- do.call(rbind,  temp.results_matrix)
 
@@ -288,61 +198,149 @@ verify_SingleGrainData <- function(
     ##SEL
     temp.results_matrix_VALID <- temp.results_matrix_RATIO > threshold
 
-    ##get structure for the RLum.Anlaysis object
-    temp_structure <- structure_RLum(object, fullExtent = TRUE)
+    ##combine everything to in a data.frame
+    selection <- data.frame(
+      POSITION = object@METADATA$POSITION,
+      GRAIN = object@METADATA$GRAIN,
+      MEAN = temp.results_matrix[, 1],
+      VAR = temp.results_matrix[, 2],
+      RATIO = temp.results_matrix_RATIO,
+      THRESHOLD = rep_len(threshold, length(object@DATA)),
+      VALID = temp.results_matrix_VALID
+    )
 
-      ##now we have two cases, depending on where measurement is coming from
-      if (object@originator == "Risoe.BINfileData2RLum.Analysis") {
+    ##get unique pairs for POSITION and GRAIN for VALID == TRUE
+    unique_pairs <- unique(
+      selection[selection[["VALID"]], c("POSITION", "GRAIN")])
 
-        ##combine everything to in a data.frame
-        selection <- data.frame(
-          POSITION = temp_structure$info.POSITION,
-          GRAIN = temp_structure$info.GRAIN,
-          MEAN = temp.results_matrix[, 1],
-          VAR = temp.results_matrix[, 2],
-          RATIO = temp.results_matrix_RATIO,
-          THRESHOLD = rep_len(threshold, length(object_list)),
-          VALID = temp.results_matrix_VALID
+    if(cleanup_level == "aliquot"){
+      selection_id <- sort(unlist(lapply(1:nrow(unique_pairs), function(x) {
+        which(
+          .subset2(selection, 1) == .subset2(unique_pairs, 1)[x] &
+            .subset2(selection, 2) == .subset2(unique_pairs, 2)[x]
         )
 
-        ##get unique pairs for POSITION and GRAIN for VALID == TRUE
-        unique_pairs <- unique(
-          selection[selection[["VALID"]], c("POSITION", "GRAIN")])
+
+      })))
 
 
-      } else if (object@originator == "read_XSYG2R") {
+    }else{
 
-        ##combine everything to in a data.frame
-        selection <- data.frame(
-          POSITION = if(any(grepl(pattern = "position", names(temp_structure)))){
-            temp_structure$info.position}else{
-              NA
-            },
-          GRAIN = NA,
-          MEAN = temp.results_matrix[, 1],
-          VAR = temp.results_matrix[, 2],
-          RATIO = temp.results_matrix_RATIO,
-          THRESHOLD = rep_len(threshold, length(object_list)),
-          VALID = temp.results_matrix_VALID
-        )
+      ##reduce data to TRUE selection
+      selection_id <- which(selection[["VALID"]])
 
-        ##get unique pairs for POSITION for VALID == TRUE
-        unique_pairs <- unique(
-          selection[["POSITION"]][selection[["VALID"]]])
+    }
 
-      } else{
 
-        stop("[verify_SingleGrainData()] I don't know what to do object 'originator' not supported!",
-             call. = FALSE)
+    ##select output on the chosen input
+    if(cleanup){
+      ##selected wanted elements
+      object@DATA <- object@DATA[selection_id]
+      object@METADATA <- object@METADATA[selection_id,]
+      object@METADATA$ID <- 1:length(object@DATA)
+
+
+      ##print message
+      selection_id <- paste(selection_id, collapse = ", ")
+      if(verbose){
+        cat(paste0("\n[verify_SingleGrainData()] Risoe.BINfileData object reduced to records: \n", selection_id))
+        cat("\n\n[verify_SingleGrainData()] Risoe.BINfileData object record index reset.\n")
+
       }
 
+      ##return
+      return_object <- object
 
-      ##set up cleanup
-      if(cleanup_level == "aliquot") {
-        if (object@originator == "read_XSYG2R") {
+    }else{
+      return_object <- set_RLum(
+        class = "RLum.Results",
+        data = list(
+          unique_pairs =  unique_pairs,
+          selection_id = selection_id,
+          selection_full = selection),
+        info = list(call = sys.call())
+      )
 
-          if(!is.na(unique_pairs)){
+    }
 
+
+    ##++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+    ##RLum.Analysis and list with RLum.Analysis objects
+    ## ... and yes it make sense not to mix that up with the code above
+  }else if(is(object,"RLum.Analysis")){
+    ##first extract all count values from all curves
+    object_list <- lapply(get_RLum(object), function(x){
+      ##yes, would work differently, but it is faster
+      x@data[,2]
+
+    })
+
+    ##MEAN + SD
+    temp.results_matrix <- lapply(X = object_list, FUN = function(x){
+      c(mean(x), var(x))
+
+    })
+
+    temp.results_matrix <- do.call(rbind,  temp.results_matrix)
+
+    ##DIFF
+    temp.results_matrix_RATIO <- temp.results_matrix[,2]/temp.results_matrix[,1]
+
+    ##SEL
+    temp.results_matrix_VALID <- temp.results_matrix_RATIO > threshold
+
+    ##get structure for the RLum.Analysis object
+    temp_structure <- structure_RLum(object, fullExtent = TRUE)
+
+    ##now we have two cases, depending on where measurement is coming from
+    if (object@originator == "Risoe.BINfileData2RLum.Analysis") {
+
+      ##combine everything to in a data.frame
+      selection <- data.frame(
+        POSITION = temp_structure$info.POSITION,
+        GRAIN = temp_structure$info.GRAIN,
+        MEAN = temp.results_matrix[, 1],
+        VAR = temp.results_matrix[, 2],
+        RATIO = temp.results_matrix_RATIO,
+        THRESHOLD = rep_len(threshold, length(object_list)),
+        VALID = temp.results_matrix_VALID
+      )
+
+      ##get unique pairs for POSITION and GRAIN for VALID == TRUE
+      unique_pairs <- unique(
+        selection[selection[["VALID"]], c("POSITION", "GRAIN")])
+
+    } else if (object@originator == "read_XSYG2R") {
+      ##combine everything to in a data.frame
+      selection <- data.frame(
+        POSITION = if(any(grepl(pattern = "position", names(temp_structure)))){
+          temp_structure$info.position}else{
+            NA
+          },
+        GRAIN = NA,
+        MEAN = temp.results_matrix[, 1],
+        VAR = temp.results_matrix[, 2],
+        RATIO = temp.results_matrix_RATIO,
+        THRESHOLD = rep_len(threshold, length(object_list)),
+        VALID = temp.results_matrix_VALID
+      )
+
+      ##get unique pairs for POSITION for VALID == TRUE
+      unique_pairs <- unique(
+        selection[["POSITION"]][selection[["VALID"]]])
+
+    } else{
+
+      stop("[verify_SingleGrainData()] I don't know what to do object 'originator' not supported!",
+           call. = FALSE)
+    }
+
+
+    ##set up cleanup
+    if(cleanup_level == "aliquot") {
+      if (object@originator == "read_XSYG2R") {
+
+        if(!is.na(unique_pairs)){
           selection_id <-
             sort(unlist(lapply(1:nrow(unique_pairs), function(x) {
               which(.subset2(selection, 1) == .subset2(unique_pairs, 1)[x])
@@ -350,35 +348,35 @@ verify_SingleGrainData <- function(
 
             })))
 
-          }else{
-           selection_id <- NA
-
-          }
-
-
-        } else if (object@originator == "Risoe.BINfileData2RLum.Analysis") {
-          selection_id <-
-            sort(unlist(lapply(1:nrow(unique_pairs), function(x) {
-              which(
-                .subset2(selection, 1) == .subset2(unique_pairs, 1)[x] &
-                  .subset2(selection, 2) == .subset2(unique_pairs, 2)[x]
-              )
-
-
-            })))
+        }else{
+          selection_id <- NA
 
         }
 
-        ##make sure that we do not break subsequent code
-        if(length(selection_id) == 0) selection_id <- NA
+
+      } else if (object@originator == "Risoe.BINfileData2RLum.Analysis") {
+        selection_id <-
+          sort(unlist(lapply(1:nrow(unique_pairs), function(x) {
+            which(
+              .subset2(selection, 1) == .subset2(unique_pairs, 1)[x] &
+                .subset2(selection, 2) == .subset2(unique_pairs, 2)[x]
+            )
 
 
-      } else{
-        ##reduce data to TRUE selection
-        selection_id <- which(selection[["VALID"]])
+          })))
 
       }
 
+      ##make sure that we do not break subsequent code
+      if(length(selection_id) == 0) selection_id <- NA
+
+
+    } else{
+      ##reduce data to TRUE selection
+      selection_id <- which(selection[["VALID"]])
+
+    }
+
 
     ##return value
     ##select output on the chosen input
@@ -388,7 +386,7 @@ verify_SingleGrainData <- function(
       if(verbose){
         selection_id_text <- paste(selection_id, collapse = ", ")
         cat(paste0("\n[verify_SingleGrainData()] RLum.Analysis object reduced to records: ",
-                   selection_id_text))
+                   selection_id_text), "\n")
 
       }
 
@@ -416,14 +414,14 @@ verify_SingleGrainData <- function(
             selection_full = selection)
         )
 
-     }
+      }
 
       ##return
       return_object <- object
 
     }else{
       if(any(is.na(selection_id))){
-        warning("[verify_SingleGrainData()] selection_id is NA, nothing removed, everything selected!",
+        warning("[verify_SingleGrainData()] selection_id is NA, nothing removed, everything selected for removal!",
                 call. = FALSE)
 
       }
@@ -447,17 +445,26 @@ verify_SingleGrainData <- function(
 
   # Plot ----------------------------------------------------------------------------------------
   if(plot){
+    ##set plot settings
+    plot_settings <-
+      modifyList(x = list(
+        main = "Record selection",
+        ylim = range(c(selection[["RATIO"]], threshold * 1.1))
+      ),
+      val = list(...))
+
+
 
     ##plot area
     plot(
       NA,
       NA,
       xlim = c(1,nrow(selection)),
-      ylim = range(selection[["RATIO"]]),
+      ylim = plot_settings$ylim,
       log = "y",
       xlab = "Record index",
       ylab = "Calculated ratio [a.u.]",
-      main = "Record selection"
+      main = plot_settings$main
     )
 
     ##plot points above the threshold
@@ -483,4 +490,3 @@ verify_SingleGrainData <- function(
 
 
 }
-
