@@ -18,11 +18,13 @@ test_that("Test internals", {
   ##check whether the objects are properly recycled
   expect_type(f(object, a = 1), "list")
   expect_length(f(object, a = 1, c = list(a = 1, b = 2, c = 3))$c, 3)
+  expect_length(f(object, a = (1), c = list(a = 1, b = 2, c = 3))$c, 3)
+  expect_equal(f(object, a = (1 + 10), c = list(a = 1, b = 2, c = 3))$a[[1]], 11)
 
   # .calc_HPDI() ------------------------------------------------------------
   set.seed(1234)
   test <- expect_type(Luminescence:::.calc_HPDI(rnorm(100), plot = TRUE), "double")
-  expect_equal(round(sum(test),2), 0.20)
+  expect_equal(round(sum(test),2), 0.20, tolerance = 1)
 
   ##create a case where the value cannot be calculated
   expect_type(.calc_HPDI(rlnorm(n = 100, meanlog = 10, sdlog = 100)), type = "logical")
@@ -88,6 +90,16 @@ test_that("Test internals", {
     ##clean-up
     rm(m)
 
+   # .download_file ---------------------------------------------------------------------------
+   ## returns just NULL (no URL detected)
+   expect_null(.download_file(url = "_url"))
+
+   ## attempts download
+   expect_message(.download_file(url = "https://raw.githubusercontent.com/R-Lum/rxylib/master/inst/extg"))
+
+    ## attempts download silently
+   expect_null(suppressMessages(
+    .download_file(url = "https://raw.githubusercontent.com/R-Lum/rxylib/master/inst/extg")))
 
   ## C++ code ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
   ##
